@@ -1,7 +1,7 @@
 #!/usr/bin/python
 import os
 from conans.server.service.authorize import BasicAuthorizer, BasicAuthenticator
-from conans.server.conf import get_file_manager
+from conans.server.conf import get_server_store
 from conans.server.rest.server import ConanServer
 from conans.server.crypto.jwt.jwt_credentials_manager import JWTCredentialsManager
 from conans.server.crypto.jwt.jwt_updown_manager import JWTUpDownAuthManager
@@ -9,8 +9,8 @@ from conans.server.conf import MIN_CLIENT_COMPATIBLE_VERSION
 from conans.server.plugin_loader import load_authentication_plugin
 from conans.model.version import Version
 from conans.server.migrate import migrate_and_get_server_config
-from conans import __version__ as SERVER_VERSION
-from conans.paths import conan_expand_user, SimplePaths
+from conans import __version__ as SERVER_VERSION, REVISIONS
+from conans.paths import conan_expand_user
 from conans import SERVER_CAPABILITIES
 
 
@@ -34,12 +34,18 @@ class ServerLauncher(object):
         updown_auth_manager = JWTUpDownAuthManager(server_config.updown_secret,
                                                    server_config.authorize_timeout)
 
-        file_manager = get_file_manager(server_config, updown_auth_manager=updown_auth_manager)
+        server_store = get_server_store(server_config.disk_storage_path,
+                                        server_config.revisions_enabled,
+                                        server_config.public_url,
+                                        updown_auth_manager=updown_auth_manager)
 
         server_capabilities = SERVER_CAPABILITIES
-        paths = SimplePaths(server_config.disk_storage_path)
+
+        if server_config.revisions_enabled:
+            server_capabilities.append(REVISIONS)
+
         self.ra = ConanServer(server_config.port, credentials_manager, updown_auth_manager,
-                              authorizer, authenticator, file_manager, paths,
+                              authorizer, authenticator, server_store,
                               Version(SERVER_VERSION), Version(MIN_CLIENT_COMPATIBLE_VERSION),
                               server_capabilities)
 
